# SPDX-FileCopyrightText: 2023-present richmr <richmr@users.noreply.github.com>
#
# SPDX-License-Identifier: MIT
import sys

if __name__ == "__main__":
    from winhotkey.cli import winhotkey

    sys.exit(winhotkey())
